@@ -1,3 +1,6 @@
+"""Test utilities for code working with files and commands"""
 from .asserts import *
 from .env import temporary_env, modified_env, make_env_restorer
 from .commands import MockCommand, assert_calls
+
+__version__ = '0.2'
